==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/SwiadczenieZwrot.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class SwiadczenieZwrot extends GenericDPSObject {
    /**
     * SWIADCZENIE_ZWROT.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * SWIADCZENIE_ZWROT.EWIDENCJA_ZGON_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long ewidencjaZgonId;

    /**
     * SWIADCZENIE_ZWROT.INSTYTUCJA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long instytucjaId;

    /**
     * SWIADCZENIE_ZWROT.SWIADCZENIE_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long swiadczenieId;

    /**
     * SWIADCZENIE_ZWROT.ZADLUZENIE_POZYCJA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long zadluzeniePozycjaId;

    /**
     * SWIADCZENIE_ZWROT.ZWROT_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long zwrotId;

    /**
     * SWIADCZENIE_ZWROT.KWOTA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal kwota;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return SWIADCZENIE_ZWROT.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * SWIADCZENIE_ZWROT.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return SWIADCZENIE_ZWROT.EWIDENCJA_ZGON_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getEwidencjaZgonId() {
        return ewidencjaZgonId;
    }

    /**
     * SWIADCZENIE_ZWROT.EWIDENCJA_ZGON_ID
     *
     * @param ewidencjaZgonId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setEwidencjaZgonId(Long ewidencjaZgonId) {
        this.ewidencjaZgonId = ewidencjaZgonId;
    }

    /**
     * @return SWIADCZENIE_ZWROT.INSTYTUCJA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getInstytucjaId() {
        return instytucjaId;
    }

    /**
     * SWIADCZENIE_ZWROT.INSTYTUCJA_ID
     *
     * @param instytucjaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setInstytucjaId(Long instytucjaId) {
        this.instytucjaId = instytucjaId;
    }

    /**
     * @return SWIADCZENIE_ZWROT.SWIADCZENIE_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getSwiadczenieId() {
        return swiadczenieId;
    }

    /**
     * SWIADCZENIE_ZWROT.SWIADCZENIE_ID
     *
     * @param swiadczenieId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setSwiadczenieId(Long swiadczenieId) {
        this.swiadczenieId = swiadczenieId;
    }

    /**
     * @return SWIADCZENIE_ZWROT.ZADLUZENIE_POZYCJA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getZadluzeniePozycjaId() {
        return zadluzeniePozycjaId;
    }

    /**
     * SWIADCZENIE_ZWROT.ZADLUZENIE_POZYCJA_ID
     *
     * @param zadluzeniePozycjaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setZadluzeniePozycjaId(Long zadluzeniePozycjaId) {
        this.zadluzeniePozycjaId = zadluzeniePozycjaId;
    }

    /**
     * @return SWIADCZENIE_ZWROT.ZWROT_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getZwrotId() {
        return zwrotId;
    }

    /**
     * SWIADCZENIE_ZWROT.ZWROT_ID
     *
     * @param zwrotId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setZwrotId(Long zwrotId) {
        this.zwrotId = zwrotId;
    }

    /**
     * @return SWIADCZENIE_ZWROT.KWOTA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getKwota() {
        return kwota;
    }

    /**
     * SWIADCZENIE_ZWROT.KWOTA
     *
     * @param kwota
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKwota(BigDecimal kwota) {
        this.kwota = kwota;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        SwiadczenieZwrot other = (SwiadczenieZwrot) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getEwidencjaZgonId() == null ? other.getEwidencjaZgonId() == null : this.getEwidencjaZgonId().equals(other.getEwidencjaZgonId()))
            && (this.getInstytucjaId() == null ? other.getInstytucjaId() == null : this.getInstytucjaId().equals(other.getInstytucjaId()))
            && (this.getSwiadczenieId() == null ? other.getSwiadczenieId() == null : this.getSwiadczenieId().equals(other.getSwiadczenieId()))
            && (this.getZadluzeniePozycjaId() == null ? other.getZadluzeniePozycjaId() == null : this.getZadluzeniePozycjaId().equals(other.getZadluzeniePozycjaId()))
            && (this.getZwrotId() == null ? other.getZwrotId() == null : this.getZwrotId().equals(other.getZwrotId()))
            && (this.getKwota() == null ? other.getKwota() == null : this.getKwota().equals(other.getKwota()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getEwidencjaZgonId() == null) ? 0 : getEwidencjaZgonId().hashCode());
        result = prime * result + ((getInstytucjaId() == null) ? 0 : getInstytucjaId().hashCode());
        result = prime * result + ((getSwiadczenieId() == null) ? 0 : getSwiadczenieId().hashCode());
        result = prime * result + ((getZadluzeniePozycjaId() == null) ? 0 : getZadluzeniePozycjaId().hashCode());
        result = prime * result + ((getZwrotId() == null) ? 0 : getZwrotId().hashCode());
        result = prime * result + ((getKwota() == null) ? 0 : getKwota().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", ewidencjaZgonId=").append(ewidencjaZgonId);
        sb.append(", instytucjaId=").append(instytucjaId);
        sb.append(", swiadczenieId=").append(swiadczenieId);
        sb.append(", zadluzeniePozycjaId=").append(zadluzeniePozycjaId);
        sb.append(", zwrotId=").append(zwrotId);
        sb.append(", kwota=").append(kwota);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/SwiadczenieZwrot.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class SwiadczenieZwrot extends GenericDPSObject {
    /**
     * SWIADCZENIE_ZWROT.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * SWIADCZENIE_ZWROT.EWIDENCJA_ZGON_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long ewidencjaZgonId;

    /**
     * SWIADCZENIE_ZWROT.INSTYTUCJA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long instytucjaId;

    /**
     * SWIADCZENIE_ZWROT.SWIADCZENIE_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long swiadczenieId;

    /**
     * SWIADCZENIE_ZWROT.ZADLUZENIE_POZYCJA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long zadluzeniePozycjaId;

    /**
     * SWIADCZENIE_ZWROT.ZWROT_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long zwrotId;

    /**
     * SWIADCZENIE_ZWROT.KWOTA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal kwota;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return SWIADCZENIE_ZWROT.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * SWIADCZENIE_ZWROT.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return SWIADCZENIE_ZWROT.EWIDENCJA_ZGON_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getEwidencjaZgonId() {
        return ewidencjaZgonId;
    }

    /**
     * SWIADCZENIE_ZWROT.EWIDENCJA_ZGON_ID
     *
     * @param ewidencjaZgonId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setEwidencjaZgonId(Long ewidencjaZgonId) {
        this.ewidencjaZgonId = ewidencjaZgonId;
    }

    /**
     * @return SWIADCZENIE_ZWROT.INSTYTUCJA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getInstytucjaId() {
        return instytucjaId;
    }

    /**
     * SWIADCZENIE_ZWROT.INSTYTUCJA_ID
     *
     * @param instytucjaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setInstytucjaId(Long instytucjaId) {
        this.instytucjaId = instytucjaId;
    }

    /**
     * @return SWIADCZENIE_ZWROT.SWIADCZENIE_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getSwiadczenieId() {
        return swiadczenieId;
    }

    /**
     * SWIADCZENIE_ZWROT.SWIADCZENIE_ID
     *
     * @param swiadczenieId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setSwiadczenieId(Long swiadczenieId) {
        this.swiadczenieId = swiadczenieId;
    }

    /**
     * @return SWIADCZENIE_ZWROT.ZADLUZENIE_POZYCJA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getZadluzeniePozycjaId() {
        return zadluzeniePozycjaId;
    }

    /**
     * SWIADCZENIE_ZWROT.ZADLUZENIE_POZYCJA_ID
     *
     * @param zadluzeniePozycjaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setZadluzeniePozycjaId(Long zadluzeniePozycjaId) {
        this.zadluzeniePozycjaId = zadluzeniePozycjaId;
    }

    /**
     * @return SWIADCZENIE_ZWROT.ZWROT_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getZwrotId() {
        return zwrotId;
    }

    /**
     * SWIADCZENIE_ZWROT.ZWROT_ID
     *
     * @param zwrotId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setZwrotId(Long zwrotId) {
        this.zwrotId = zwrotId;
    }

    /**
     * @return SWIADCZENIE_ZWROT.KWOTA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getKwota() {
        return kwota;
    }

    /**
     * SWIADCZENIE_ZWROT.KWOTA
     *
     * @param kwota
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKwota(BigDecimal kwota) {
        this.kwota = kwota;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        SwiadczenieZwrot other = (SwiadczenieZwrot) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getEwidencjaZgonId() == null ? other.getEwidencjaZgonId() == null : this.getEwidencjaZgonId().equals(other.getEwidencjaZgonId()))
            && (this.getInstytucjaId() == null ? other.getInstytucjaId() == null : this.getInstytucjaId().equals(other.getInstytucjaId()))
            && (this.getSwiadczenieId() == null ? other.getSwiadczenieId() == null : this.getSwiadczenieId().equals(other.getSwiadczenieId()))
            && (this.getZadluzeniePozycjaId() == null ? other.getZadluzeniePozycjaId() == null : this.getZadluzeniePozycjaId().equals(other.getZadluzeniePozycjaId()))
            && (this.getZwrotId() == null ? other.getZwrotId() == null : this.getZwrotId().equals(other.getZwrotId()))
            && (this.getKwota() == null ? other.getKwota() == null : this.getKwota().equals(other.getKwota()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getEwidencjaZgonId() == null) ? 0 : getEwidencjaZgonId().hashCode());
        result = prime * result + ((getInstytucjaId() == null) ? 0 : getInstytucjaId().hashCode());
        result = prime * result + ((getSwiadczenieId() == null) ? 0 : getSwiadczenieId().hashCode());
        result = prime * result + ((getZadluzeniePozycjaId() == null) ? 0 : getZadluzeniePozycjaId().hashCode());
        result = prime * result + ((getZwrotId() == null) ? 0 : getZwrotId().hashCode());
        result = prime * result + ((getKwota() == null) ? 0 : getKwota().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", ewidencjaZgonId=").append(ewidencjaZgonId);
        sb.append(", instytucjaId=").append(instytucjaId);
        sb.append(", swiadczenieId=").append(swiadczenieId);
        sb.append(", zadluzeniePozycjaId=").append(zadluzeniePozycjaId);
        sb.append(", zwrotId=").append(zwrotId);
        sb.append(", kwota=").append(kwota);
        sb.append("]");
        return sb.toString();
    }
}
